macro_rules! lbup {
( $x:expr ) => { ... };
}Expand description
macro for creating LBox<dyn Any> structures that can encapsulate any type
as abstract syntax. Must be called from within the semantic actions of
a grammar production rule.
macro_rules! lbup {
( $x:expr ) => { ... };
}macro for creating LBox<dyn Any> structures that can encapsulate any type
as abstract syntax. Must be called from within the semantic actions of
a grammar production rule.